@@ -117,13 +117,11 @@ g_data_input_stream_set_property (GObject      *object,
 				  const GValue *value,
 				  GParamSpec   *pspec)
 {
-  GDataInputStreamPrivate *priv;
   GDataInputStream        *dstream;
 
   dstream = G_DATA_INPUT_STREAM (object);
-  priv = dstream->priv;
 
-   switch (prop_id) 
+   switch (prop_id)
     {
     case PROP_BYTE_ORDER:
       g_data_input_stream_set_byte_order (dstream, g_value_get_enum (value));
@@ -315,7 +313,7 @@ read_data (GDataInputStream  *stream,
 	}
     }
   
-  /* This should always succeed, since its in the buffer */
+  /* This should always succeed, since it's in the buffer */
   res = g_input_stream_read (G_INPUT_STREAM (stream),
 			     buffer, size,
 			     NULL, NULL);
@@ -737,15 +735,15 @@ scan_for_newline (GDataInputStream *stream,
  * @error: #GError for error reporting.
  *
  * Reads a line from the data input stream.
- * 
+ *
  * If @cancellable is not %NULL, then the operation can be cancelled by
  * triggering the cancellable object from another thread. If the operation
- * was cancelled, the error %G_IO_ERROR_CANCELLED will be returned. 
- * 
+ * was cancelled, the error %G_IO_ERROR_CANCELLED will be returned.
+ *
  * Returns: a string with the line that was read in (without the newlines).
- * Set @length to a #gsize to get the length of the read line.
- * On an error, it will return %NULL and @error will be set. If there's no
- * content to read, it will still return %NULL, but @error won't be set.
+ *     Set @length to a #gsize to get the length of the read line.
+ *     On an error, it will return %NULL and @error will be set. If there's no
+ *     content to read, it will still return %NULL, but @error won't be set.
  **/
 char *
 g_data_input_stream_read_line (GDataInputStream  *stream,
@@ -817,21 +815,16 @@ scan_for_chars (GDataInputStream *stream,
 		const char       *stop_chars)
 {
   GBufferedInputStream *bstream;
-  GDataInputStreamPrivate *priv;
   const char *buffer;
   gsize start, end, peeked;
   int i;
-  gssize found_pos;
   gsize available, checked;
   const char *stop_char;
 
-  priv = stream->priv;
-  
   bstream = G_BUFFERED_INPUT_STREAM (stream);
 
   checked = *checked_out;
-  found_pos = -1;
-  
+
   start = checked;
   buffer = (const char *)g_buffered_input_stream_peek_buffer (bstream, &available) + start;
   end = available;
@@ -859,14 +852,14 @@ scan_for_chars (GDataInputStream *stream,
  * @length: a #gsize to get the length of the data read in.
  * @cancellable: optional #GCancellable object, %NULL to ignore.
  * @error: #GError for error reporting.
- * 
- * Reads a string from the data input stream, up to the first 
+ *
+ * Reads a string from the data input stream, up to the first
  * occurrence of any of the stop characters.
  *
- * Returns: a string with the data that was read before encountering 
- * any of the stop characters. Set @length to a #gsize to get the length 
- * of the string. This function will return %NULL on an error.
- **/
+ * Returns: a string with the data that was read before encountering
+ *     any of the stop characters. Set @length to a #gsize to get the length
+ *     of the string. This function will return %NULL on an error.
+ */
 char *
 g_data_input_stream_read_until (GDataInputStream  *stream,
 			       const gchar        *stop_chars,
@@ -1122,15 +1115,21 @@ g_data_input_stream_read_finish (GDataInputStream  *stream,
 /**
  * g_data_input_stream_read_line_async:
  * @stream: a given #GDataInputStream.
- * @io_priority: the <link linkend="io-priority">I/O priority</link> 
- * of the request. 
+ * @io_priority: the <link linkend="io-priority">I/O priority</link>
+ *     of the request.
  * @cancellable: optional #GCancellable object, %NULL to ignore.
  * @callback: callback to call when the request is satisfied.
  * @user_data: the data to pass to callback function.
  *
  * The asynchronous version of g_data_input_stream_read_line().  It is
  * an error to have two outstanding calls to this function.
- **/
+ *
+ * When the operation is finished, @callback will be called. You
+ * can then call g_data_input_stream_read_line_finish() to get
+ * the result of the operation.
+ *
+ * Since: 2.20
+ */
 void
 g_data_input_stream_read_line_async (GDataInputStream    *stream,
                                      gint                 io_priority,
@@ -1150,15 +1149,21 @@ g_data_input_stream_read_line_async (GDataInputStream    *stream,
  * g_data_input_stream_read_until_async:
  * @stream: a given #GDataInputStream.
  * @stop_chars: characters to terminate the read.
- * @io_priority: the <link linkend="io-priority">I/O priority</link> 
- * of the request. 
+ * @io_priority: the <link linkend="io-priority">I/O priority</link>
+ *     of the request.
  * @cancellable: optional #GCancellable object, %NULL to ignore.
  * @callback: callback to call when the request is satisfied.
  * @user_data: the data to pass to callback function.
  *
- * The asynchronous version of g_data_input_stream_read_until().  It is
- * an error to have two outstanding calls to this function.
- **/
+ * The asynchronous version of g_data_input_stream_read_until().
+ * It is an error to have two outstanding calls to this function.
+ *
+ * When the operation is finished, @callback will be called. You
+ * can then call g_data_input_stream_read_until_finish() to get
+ * the result of the operation.
+ *
+ * Since: 2.20
+ */
 void
 g_data_input_stream_read_until_async (GDataInputStream    *stream,
                                       const gchar         *stop_chars,
@@ -1185,7 +1190,14 @@ g_data_input_stream_read_until_async (GDataInputStream    *stream,
  *
  * Finish an asynchronous call started by
  * g_data_input_stream_read_line_async().
- **/
+ *
+ * Returns: a string with the line that was read in (without the newlines).
+ *     Set @length to a #gsize to get the length of the read line.
+ *     On an error, it will return %NULL and @error will be set. If there's no
+ *     content to read, it will still return %NULL, but @error won't be set.
+ *
+ * Since: 2.20
+ */
 gchar *
 g_data_input_stream_read_line_finish (GDataInputStream  *stream,
                                       GAsyncResult      *result,
@@ -1208,7 +1220,13 @@ g_data_input_stream_read_line_finish (GDataInputStream  *stream,
  *
  * Finish an asynchronous call started by
  * g_data_input_stream_read_until_async().
- **/
+ *
+ * Since: 2.20
+ *
+ * Returns: a string with the data that was read before encountering
+ *     any of the stop characters. Set @length to a #gsize to get the length
+ *     of the string. This function will return %NULL on an error.
+ */
 gchar *
 g_data_input_stream_read_until_finish (GDataInputStream  *stream,
                                        GAsyncResult      *result,
@@ -1222,5 +1240,6 @@ g_data_input_stream_read_until_finish (GDataInputStream  *stream,
   return g_data_input_stream_read_finish (stream, result, length, error);
 }
 
+
 #define __G_DATA_INPUT_STREAM_C__
 #include "gioaliasdef.c"
