@@ -308,12 +308,6 @@ canonicalize_filename (const char *filename)
   return canon;
 }
 
-/**
- * _g_local_file_new:
- * @filename: filename of the file to create.
- * 
- * Returns: new local #GFile.
- **/
 GFile *
 _g_local_file_new (const char *filename)
 {
@@ -1105,8 +1099,6 @@ g_local_file_set_display_name (GFile         *file,
   GLocalFile *local, *new_local;
   GFile *new_file, *parent;
   struct _g_stat_struct statbuf;
-  GVfsClass *class;
-  GVfs *vfs;
   int errsv;
 
   parent = g_file_get_parent (file);
@@ -1165,12 +1157,7 @@ g_local_file_set_display_name (GFile         *file,
       g_object_unref (new_file);
       return NULL;
     }
-
-  vfs = g_vfs_get_default ();
-  class = G_VFS_GET_CLASS (vfs);
-  if (class->local_file_moved)
-    class->local_file_moved (vfs, local->filename, new_local->filename);
-
+  
   return new_file;
 }
 
@@ -1810,9 +1797,7 @@ g_local_file_trash (GFile         *file,
   int fd;
   struct _g_stat_struct trash_stat, global_stat;
   char *dirname, *globaldir;
-  GVfsClass *class;
-  GVfs *vfs;
-
+  
   if (g_lstat (local->filename, &file_stat) != 0)
     {
       int errsv = errno;
@@ -2035,11 +2020,6 @@ g_local_file_trash (GFile         *file,
       return FALSE;
     }
 
-  vfs = g_vfs_get_default ();
-  class = G_VFS_GET_CLASS (vfs);
-  if (class->local_file_moved)
-    class->local_file_moved (vfs, local->filename, trashfile);
-
   g_free (trashfile);
 
   /* TODO: Do we need to update mtime/atime here after the move? */
@@ -2170,6 +2150,10 @@ g_local_file_make_symbolic_link (GFile         *file,
 	g_set_error_literal (error, G_IO_ERROR,
                              G_IO_ERROR_INVALID_FILENAME,
                              _("Invalid filename"));
+      else if (errsv == EPERM)
+	g_set_error (error, G_IO_ERROR,
+		     G_IO_ERROR_NOT_SUPPORTED,
+		     _("Filesystem does not support symbolic links"));
       else
 	g_set_error (error, G_IO_ERROR,
 		     g_io_error_from_errno (errsv),
