@@ -1,12 +1,57 @@
 
 
+#ifdef G_ENABLE_DEBUG
+#define g_marshal_value_peek_boolean(v)  g_value_get_boolean (v)
+#define g_marshal_value_peek_char(v)     g_value_get_char (v)
+#define g_marshal_value_peek_uchar(v)    g_value_get_uchar (v)
+#define g_marshal_value_peek_int(v)      g_value_get_int (v)
+#define g_marshal_value_peek_uint(v)     g_value_get_uint (v)
+#define g_marshal_value_peek_long(v)     g_value_get_long (v)
+#define g_marshal_value_peek_ulong(v)    g_value_get_ulong (v)
+#define g_marshal_value_peek_int64(v)    g_value_get_int64 (v)
+#define g_marshal_value_peek_uint64(v)   g_value_get_uint64 (v)
+#define g_marshal_value_peek_enum(v)     g_value_get_enum (v)
+#define g_marshal_value_peek_flags(v)    g_value_get_flags (v)
+#define g_marshal_value_peek_float(v)    g_value_get_float (v)
+#define g_marshal_value_peek_double(v)   g_value_get_double (v)
+#define g_marshal_value_peek_string(v)   (char*) g_value_get_string (v)
+#define g_marshal_value_peek_param(v)    g_value_get_param (v)
+#define g_marshal_value_peek_boxed(v)    g_value_get_boxed (v)
+#define g_marshal_value_peek_pointer(v)  g_value_get_pointer (v)
+#define g_marshal_value_peek_object(v)   g_value_get_object (v)
+#else /* !G_ENABLE_DEBUG */
+/* WARNING: This code accesses GValues directly, which is UNSUPPORTED API.
+ *          Do not access GValues directly in your code. Instead, use the
+ *          g_value_get_*() functions
+ */
+#define g_marshal_value_peek_boolean(v)  (v)->data[0].v_int
+#define g_marshal_value_peek_char(v)     (v)->data[0].v_int
+#define g_marshal_value_peek_uchar(v)    (v)->data[0].v_uint
+#define g_marshal_value_peek_int(v)      (v)->data[0].v_int
+#define g_marshal_value_peek_uint(v)     (v)->data[0].v_uint
+#define g_marshal_value_peek_long(v)     (v)->data[0].v_long
+#define g_marshal_value_peek_ulong(v)    (v)->data[0].v_ulong
+#define g_marshal_value_peek_int64(v)    (v)->data[0].v_int64
+#define g_marshal_value_peek_uint64(v)   (v)->data[0].v_uint64
+#define g_marshal_value_peek_enum(v)     (v)->data[0].v_long
+#define g_marshal_value_peek_flags(v)    (v)->data[0].v_ulong
+#define g_marshal_value_peek_float(v)    (v)->data[0].v_float
+#define g_marshal_value_peek_double(v)   (v)->data[0].v_double
+#define g_marshal_value_peek_string(v)   (v)->data[0].v_pointer
+#define g_marshal_value_peek_param(v)    (v)->data[0].v_pointer
+#define g_marshal_value_peek_boxed(v)    (v)->data[0].v_pointer
+#define g_marshal_value_peek_pointer(v)  (v)->data[0].v_pointer
+#define g_marshal_value_peek_object(v)   (v)->data[0].v_pointer
+#endif /* !G_ENABLE_DEBUG */
+
+
 /* VOID:VOID (./gmarshal.list:26) */
 void
 g_cclosure_marshal_VOID__VOID (GClosure     *closure,
-                               GValue       *return_value,
+                               GValue       *return_value G_GNUC_UNUSED,
                                guint         n_param_values,
                                const GValue *param_values,
-                               gpointer      invocation_hint,
+                               gpointer      invocation_hint G_GNUC_UNUSED,
                                gpointer      marshal_data)
 {
   typedef void (*GMarshalFunc_VOID__VOID) (gpointer     data1,
@@ -36,10 +81,10 @@ g_cclosure_marshal_VOID__VOID (GClosure     *closure,
 /* VOID:BOOLEAN (./gmarshal.list:27) */
 void
 g_cclosure_marshal_VOID__BOOLEAN (GClosure     *closure,
-                                  GValue       *return_value,
+                                  GValue       *return_value G_GNUC_UNUSED,
                                   guint         n_param_values,
                                   const GValue *param_values,
-                                  gpointer      invocation_hint,
+                                  gpointer      invocation_hint G_GNUC_UNUSED,
                                   gpointer      marshal_data)
 {
   typedef void (*GMarshalFunc_VOID__BOOLEAN) (gpointer     data1,
@@ -64,17 +109,17 @@ g_cclosure_marshal_VOID__BOOLEAN (GClosure     *closure,
   callback = (GMarshalFunc_VOID__BOOLEAN) (marshal_data ? marshal_data : cc->callback);
 
   callback (data1,
-            g_value_get_boolean (param_values + 1),
+            g_marshal_value_peek_boolean (param_values + 1),
             data2);
 }
 
 /* VOID:CHAR (./gmarshal.list:28) */
 void
 g_cclosure_marshal_VOID__CHAR (GClosure     *closure,
-                               GValue       *return_value,
+                               GValue       *return_value G_GNUC_UNUSED,
                                guint         n_param_values,
                                const GValue *param_values,
-                               gpointer      invocation_hint,
+                               gpointer      invocation_hint G_GNUC_UNUSED,
                                gpointer      marshal_data)
 {
   typedef void (*GMarshalFunc_VOID__CHAR) (gpointer     data1,
@@ -99,17 +144,17 @@ g_cclosure_marshal_VOID__CHAR (GClosure     *closure,
   callback = (GMarshalFunc_VOID__CHAR) (marshal_data ? marshal_data : cc->callback);
 
   callback (data1,
-            g_value_get_char (param_values + 1),
+            g_marshal_value_peek_char (param_values + 1),
             data2);
 }
 
 /* VOID:UCHAR (./gmarshal.list:29) */
 void
 g_cclosure_marshal_VOID__UCHAR (GClosure     *closure,
-                                GValue       *return_value,
+                                GValue       *return_value G_GNUC_UNUSED,
                                 guint         n_param_values,
                                 const GValue *param_values,
-                                gpointer      invocation_hint,
+                                gpointer      invocation_hint G_GNUC_UNUSED,
                                 gpointer      marshal_data)
 {
   typedef void (*GMarshalFunc_VOID__UCHAR) (gpointer     data1,
@@ -134,17 +179,17 @@ g_cclosure_marshal_VOID__UCHAR (GClosure     *closure,
   callback = (GMarshalFunc_VOID__UCHAR) (marshal_data ? marshal_data : cc->callback);
 
   callback (data1,
-            g_value_get_uchar (param_values + 1),
+            g_marshal_value_peek_uchar (param_values + 1),
             data2);
 }
 
 /* VOID:INT (./gmarshal.list:30) */
 void
 g_cclosure_marshal_VOID__INT (GClosure     *closure,
-                              GValue       *return_value,
+                              GValue       *return_value G_GNUC_UNUSED,
                               guint         n_param_values,
                               const GValue *param_values,
-                              gpointer      invocation_hint,
+                              gpointer      invocation_hint G_GNUC_UNUSED,
                               gpointer      marshal_data)
 {
   typedef void (*GMarshalFunc_VOID__INT) (gpointer     data1,
@@ -169,17 +214,17 @@ g_cclosure_marshal_VOID__INT (GClosure     *closure,
   callback = (GMarshalFunc_VOID__INT) (marshal_data ? marshal_data : cc->callback);
 
   callback (data1,
-            g_value_get_int (param_values + 1),
+            g_marshal_value_peek_int (param_values + 1),
             data2);
 }
 
 /* VOID:UINT (./gmarshal.list:31) */
 void
 g_cclosure_marshal_VOID__UINT (GClosure     *closure,
-                               GValue       *return_value,
+                               GValue       *return_value G_GNUC_UNUSED,
                                guint         n_param_values,
                                const GValue *param_values,
-                               gpointer      invocation_hint,
+                               gpointer      invocation_hint G_GNUC_UNUSED,
                                gpointer      marshal_data)
 {
   typedef void (*GMarshalFunc_VOID__UINT) (gpointer     data1,
@@ -204,17 +249,17 @@ g_cclosure_marshal_VOID__UINT (GClosure     *closure,
   callback = (GMarshalFunc_VOID__UINT) (marshal_data ? marshal_data : cc->callback);
 
   callback (data1,
-            g_value_get_uint (param_values + 1),
+            g_marshal_value_peek_uint (param_values + 1),
             data2);
 }
 
 /* VOID:LONG (./gmarshal.list:32) */
 void
 g_cclosure_marshal_VOID__LONG (GClosure     *closure,
-                               GValue       *return_value,
+                               GValue       *return_value G_GNUC_UNUSED,
                                guint         n_param_values,
                                const GValue *param_values,
-                               gpointer      invocation_hint,
+                               gpointer      invocation_hint G_GNUC_UNUSED,
                                gpointer      marshal_data)
 {
   typedef void (*GMarshalFunc_VOID__LONG) (gpointer     data1,
@@ -239,17 +284,17 @@ g_cclosure_marshal_VOID__LONG (GClosure     *closure,
   callback = (GMarshalFunc_VOID__LONG) (marshal_data ? marshal_data : cc->callback);
 
   callback (data1,
-            g_value_get_long (param_values + 1),
+            g_marshal_value_peek_long (param_values + 1),
             data2);
 }
 
 /* VOID:ULONG (./gmarshal.list:33) */
 void
 g_cclosure_marshal_VOID__ULONG (GClosure     *closure,
-                                GValue       *return_value,
+                                GValue       *return_value G_GNUC_UNUSED,
                                 guint         n_param_values,
                                 const GValue *param_values,
-                                gpointer      invocation_hint,
+                                gpointer      invocation_hint G_GNUC_UNUSED,
                                 gpointer      marshal_data)
 {
   typedef void (*GMarshalFunc_VOID__ULONG) (gpointer     data1,
@@ -274,17 +319,17 @@ g_cclosure_marshal_VOID__ULONG (GClosure     *closure,
   callback = (GMarshalFunc_VOID__ULONG) (marshal_data ? marshal_data : cc->callback);
 
   callback (data1,
-            g_value_get_ulong (param_values + 1),
+            g_marshal_value_peek_ulong (param_values + 1),
             data2);
 }
 
 /* VOID:ENUM (./gmarshal.list:34) */
 void
 g_cclosure_marshal_VOID__ENUM (GClosure     *closure,
-                               GValue       *return_value,
+                               GValue       *return_value G_GNUC_UNUSED,
                                guint         n_param_values,
                                const GValue *param_values,
-                               gpointer      invocation_hint,
+                               gpointer      invocation_hint G_GNUC_UNUSED,
                                gpointer      marshal_data)
 {
   typedef void (*GMarshalFunc_VOID__ENUM) (gpointer     data1,
@@ -309,17 +354,17 @@ g_cclosure_marshal_VOID__ENUM (GClosure     *closure,
   callback = (GMarshalFunc_VOID__ENUM) (marshal_data ? marshal_data : cc->callback);
 
   callback (data1,
-            g_value_get_enum (param_values + 1),
+            g_marshal_value_peek_enum (param_values + 1),
             data2);
 }
 
 /* VOID:FLAGS (./gmarshal.list:35) */
 void
 g_cclosure_marshal_VOID__FLAGS (GClosure     *closure,
-                                GValue       *return_value,
+                                GValue       *return_value G_GNUC_UNUSED,
                                 guint         n_param_values,
                                 const GValue *param_values,
-                                gpointer      invocation_hint,
+                                gpointer      invocation_hint G_GNUC_UNUSED,
                                 gpointer      marshal_data)
 {
   typedef void (*GMarshalFunc_VOID__FLAGS) (gpointer     data1,
@@ -344,17 +389,17 @@ g_cclosure_marshal_VOID__FLAGS (GClosure     *closure,
   callback = (GMarshalFunc_VOID__FLAGS) (marshal_data ? marshal_data : cc->callback);
 
   callback (data1,
-            g_value_get_flags (param_values + 1),
+            g_marshal_value_peek_flags (param_values + 1),
             data2);
 }
 
 /* VOID:FLOAT (./gmarshal.list:36) */
 void
 g_cclosure_marshal_VOID__FLOAT (GClosure     *closure,
-                                GValue       *return_value,
+                                GValue       *return_value G_GNUC_UNUSED,
                                 guint         n_param_values,
                                 const GValue *param_values,
-                                gpointer      invocation_hint,
+                                gpointer      invocation_hint G_GNUC_UNUSED,
                                 gpointer      marshal_data)
 {
   typedef void (*GMarshalFunc_VOID__FLOAT) (gpointer     data1,
@@ -379,17 +424,17 @@ g_cclosure_marshal_VOID__FLOAT (GClosure     *closure,
   callback = (GMarshalFunc_VOID__FLOAT) (marshal_data ? marshal_data : cc->callback);
 
   callback (data1,
-            g_value_get_float (param_values + 1),
+            g_marshal_value_peek_float (param_values + 1),
             data2);
 }
 
 /* VOID:DOUBLE (./gmarshal.list:37) */
 void
 g_cclosure_marshal_VOID__DOUBLE (GClosure     *closure,
-                                 GValue       *return_value,
+                                 GValue       *return_value G_GNUC_UNUSED,
                                  guint         n_param_values,
                                  const GValue *param_values,
-                                 gpointer      invocation_hint,
+                                 gpointer      invocation_hint G_GNUC_UNUSED,
                                  gpointer      marshal_data)
 {
   typedef void (*GMarshalFunc_VOID__DOUBLE) (gpointer     data1,
@@ -414,17 +459,17 @@ g_cclosure_marshal_VOID__DOUBLE (GClosure     *closure,
   callback = (GMarshalFunc_VOID__DOUBLE) (marshal_data ? marshal_data : cc->callback);
 
   callback (data1,
-            g_value_get_double (param_values + 1),
+            g_marshal_value_peek_double (param_values + 1),
             data2);
 }
 
 /* VOID:STRING (./gmarshal.list:38) */
 void
 g_cclosure_marshal_VOID__STRING (GClosure     *closure,
-                                 GValue       *return_value,
+                                 GValue       *return_value G_GNUC_UNUSED,
                                  guint         n_param_values,
                                  const GValue *param_values,
-                                 gpointer      invocation_hint,
+                                 gpointer      invocation_hint G_GNUC_UNUSED,
                                  gpointer      marshal_data)
 {
   typedef void (*GMarshalFunc_VOID__STRING) (gpointer     data1,
@@ -449,17 +494,17 @@ g_cclosure_marshal_VOID__STRING (GClosure     *closure,
   callback = (GMarshalFunc_VOID__STRING) (marshal_data ? marshal_data : cc->callback);
 
   callback (data1,
-            (char*) g_value_get_string (param_values + 1),
+            g_marshal_value_peek_string (param_values + 1),
             data2);
 }
 
 /* VOID:PARAM (./gmarshal.list:39) */
 void
 g_cclosure_marshal_VOID__PARAM (GClosure     *closure,
-                                GValue       *return_value,
+                                GValue       *return_value G_GNUC_UNUSED,
                                 guint         n_param_values,
                                 const GValue *param_values,
-                                gpointer      invocation_hint,
+                                gpointer      invocation_hint G_GNUC_UNUSED,
                                 gpointer      marshal_data)
 {
   typedef void (*GMarshalFunc_VOID__PARAM) (gpointer     data1,
@@ -484,17 +529,17 @@ g_cclosure_marshal_VOID__PARAM (GClosure     *closure,
   callback = (GMarshalFunc_VOID__PARAM) (marshal_data ? marshal_data : cc->callback);
 
   callback (data1,
-            g_value_get_param (param_values + 1),
+            g_marshal_value_peek_param (param_values + 1),
             data2);
 }
 
 /* VOID:BOXED (./gmarshal.list:40) */
 void
 g_cclosure_marshal_VOID__BOXED (GClosure     *closure,
-                                GValue       *return_value,
+                                GValue       *return_value G_GNUC_UNUSED,
                                 guint         n_param_values,
                                 const GValue *param_values,
-                                gpointer      invocation_hint,
+                                gpointer      invocation_hint G_GNUC_UNUSED,
                                 gpointer      marshal_data)
 {
   typedef void (*GMarshalFunc_VOID__BOXED) (gpointer     data1,
@@ -519,17 +564,17 @@ g_cclosure_marshal_VOID__BOXED (GClosure     *closure,
   callback = (GMarshalFunc_VOID__BOXED) (marshal_data ? marshal_data : cc->callback);
 
   callback (data1,
-            g_value_get_boxed (param_values + 1),
+            g_marshal_value_peek_boxed (param_values + 1),
             data2);
 }
 
 /* VOID:POINTER (./gmarshal.list:41) */
 void
 g_cclosure_marshal_VOID__POINTER (GClosure     *closure,
-                                  GValue       *return_value,
+                                  GValue       *return_value G_GNUC_UNUSED,
                                   guint         n_param_values,
                                   const GValue *param_values,
-                                  gpointer      invocation_hint,
+                                  gpointer      invocation_hint G_GNUC_UNUSED,
                                   gpointer      marshal_data)
 {
   typedef void (*GMarshalFunc_VOID__POINTER) (gpointer     data1,
@@ -554,17 +599,17 @@ g_cclosure_marshal_VOID__POINTER (GClosure     *closure,
   callback = (GMarshalFunc_VOID__POINTER) (marshal_data ? marshal_data : cc->callback);
 
   callback (data1,
-            g_value_get_pointer (param_values + 1),
+            g_marshal_value_peek_pointer (param_values + 1),
             data2);
 }
 
 /* VOID:OBJECT (./gmarshal.list:42) */
 void
 g_cclosure_marshal_VOID__OBJECT (GClosure     *closure,
-                                 GValue       *return_value,
+                                 GValue       *return_value G_GNUC_UNUSED,
                                  guint         n_param_values,
                                  const GValue *param_values,
-                                 gpointer      invocation_hint,
+                                 gpointer      invocation_hint G_GNUC_UNUSED,
                                  gpointer      marshal_data)
 {
   typedef void (*GMarshalFunc_VOID__OBJECT) (gpointer     data1,
@@ -589,17 +634,93 @@ g_cclosure_marshal_VOID__OBJECT (GClosure     *closure,
   callback = (GMarshalFunc_VOID__OBJECT) (marshal_data ? marshal_data : cc->callback);
 
   callback (data1,
-            g_value_get_object (param_values + 1),
+            g_marshal_value_peek_object (param_values + 1),
             data2);
 }
 
-/* STRING:OBJECT,POINTER (./gmarshal.list:43) */
+/* VOID:UINT,POINTER (./gmarshal.list:45) */
+void
+g_cclosure_marshal_VOID__UINT_POINTER (GClosure     *closure,
+                                       GValue       *return_value G_GNUC_UNUSED,
+                                       guint         n_param_values,
+                                       const GValue *param_values,
+                                       gpointer      invocation_hint G_GNUC_UNUSED,
+                                       gpointer      marshal_data)
+{
+  typedef void (*GMarshalFunc_VOID__UINT_POINTER) (gpointer     data1,
+                                                   guint        arg_1,
+                                                   gpointer     arg_2,
+                                                   gpointer     data2);
+  register GMarshalFunc_VOID__UINT_POINTER callback;
+  register GCClosure *cc = (GCClosure*) closure;
+  register gpointer data1, data2;
+
+  g_return_if_fail (n_param_values == 3);
+
+  if (G_CCLOSURE_SWAP_DATA (closure))
+    {
+      data1 = closure->data;
+      data2 = g_value_peek_pointer (param_values + 0);
+    }
+  else
+    {
+      data1 = g_value_peek_pointer (param_values + 0);
+      data2 = closure->data;
+    }
+  callback = (GMarshalFunc_VOID__UINT_POINTER) (marshal_data ? marshal_data : cc->callback);
+
+  callback (data1,
+            g_marshal_value_peek_uint (param_values + 1),
+            g_marshal_value_peek_pointer (param_values + 2),
+            data2);
+}
+
+/* BOOL:FLAGS (./gmarshal.list:46) */
+void
+g_cclosure_marshal_BOOLEAN__FLAGS (GClosure     *closure,
+                                   GValue       *return_value G_GNUC_UNUSED,
+                                   guint         n_param_values,
+                                   const GValue *param_values,
+                                   gpointer      invocation_hint G_GNUC_UNUSED,
+                                   gpointer      marshal_data)
+{
+  typedef gboolean (*GMarshalFunc_BOOLEAN__FLAGS) (gpointer     data1,
+                                                   guint        arg_1,
+                                                   gpointer     data2);
+  register GMarshalFunc_BOOLEAN__FLAGS callback;
+  register GCClosure *cc = (GCClosure*) closure;
+  register gpointer data1, data2;
+  gboolean v_return;
+
+  g_return_if_fail (return_value != NULL);
+  g_return_if_fail (n_param_values == 2);
+
+  if (G_CCLOSURE_SWAP_DATA (closure))
+    {
+      data1 = closure->data;
+      data2 = g_value_peek_pointer (param_values + 0);
+    }
+  else
+    {
+      data1 = g_value_peek_pointer (param_values + 0);
+      data2 = closure->data;
+    }
+  callback = (GMarshalFunc_BOOLEAN__FLAGS) (marshal_data ? marshal_data : cc->callback);
+
+  v_return = callback (data1,
+                       g_marshal_value_peek_flags (param_values + 1),
+                       data2);
+
+  g_value_set_boolean (return_value, v_return);
+}
+
+/* STRING:OBJECT,POINTER (./gmarshal.list:47) */
 void
 g_cclosure_marshal_STRING__OBJECT_POINTER (GClosure     *closure,
-                                           GValue       *return_value,
+                                           GValue       *return_value G_GNUC_UNUSED,
                                            guint         n_param_values,
                                            const GValue *param_values,
-                                           gpointer      invocation_hint,
+                                           gpointer      invocation_hint G_GNUC_UNUSED,
                                            gpointer      marshal_data)
 {
   typedef gchar* (*GMarshalFunc_STRING__OBJECT_POINTER) (gpointer     data1,
@@ -627,86 +748,10 @@ g_cclosure_marshal_STRING__OBJECT_POINTER (GClosure     *closure,
   callback = (GMarshalFunc_STRING__OBJECT_POINTER) (marshal_data ? marshal_data : cc->callback);
 
   v_return = callback (data1,
-                       g_value_get_object (param_values + 1),
-                       g_value_get_pointer (param_values + 2),
+                       g_marshal_value_peek_object (param_values + 1),
+                       g_marshal_value_peek_pointer (param_values + 2),
                        data2);
 
-  g_value_set_string_take_ownership (return_value, v_return);
-}
-
-/* VOID:UINT,POINTER (./gmarshal.list:46) */
-void
-g_cclosure_marshal_VOID__UINT_POINTER (GClosure     *closure,
-                                       GValue       *return_value,
-                                       guint         n_param_values,
-                                       const GValue *param_values,
-                                       gpointer      invocation_hint,
-                                       gpointer      marshal_data)
-{
-  typedef void (*GMarshalFunc_VOID__UINT_POINTER) (gpointer     data1,
-                                                   guint        arg_1,
-                                                   gpointer     arg_2,
-                                                   gpointer     data2);
-  register GMarshalFunc_VOID__UINT_POINTER callback;
-  register GCClosure *cc = (GCClosure*) closure;
-  register gpointer data1, data2;
-
-  g_return_if_fail (n_param_values == 3);
-
-  if (G_CCLOSURE_SWAP_DATA (closure))
-    {
-      data1 = closure->data;
-      data2 = g_value_peek_pointer (param_values + 0);
-    }
-  else
-    {
-      data1 = g_value_peek_pointer (param_values + 0);
-      data2 = closure->data;
-    }
-  callback = (GMarshalFunc_VOID__UINT_POINTER) (marshal_data ? marshal_data : cc->callback);
-
-  callback (data1,
-            g_value_get_uint (param_values + 1),
-            g_value_get_pointer (param_values + 2),
-            data2);
-}
-
-/* BOOL:FLAGS (./gmarshal.list:47) */
-void
-g_cclosure_marshal_BOOLEAN__FLAGS (GClosure     *closure,
-                                   GValue       *return_value,
-                                   guint         n_param_values,
-                                   const GValue *param_values,
-                                   gpointer      invocation_hint,
-                                   gpointer      marshal_data)
-{
-  typedef gboolean (*GMarshalFunc_BOOLEAN__FLAGS) (gpointer     data1,
-                                                   guint        arg_1,
-                                                   gpointer     data2);
-  register GMarshalFunc_BOOLEAN__FLAGS callback;
-  register GCClosure *cc = (GCClosure*) closure;
-  register gpointer data1, data2;
-  gboolean v_return;
-
-  g_return_if_fail (return_value != NULL);
-  g_return_if_fail (n_param_values == 2);
-
-  if (G_CCLOSURE_SWAP_DATA (closure))
-    {
-      data1 = closure->data;
-      data2 = g_value_peek_pointer (param_values + 0);
-    }
-  else
-    {
-      data1 = g_value_peek_pointer (param_values + 0);
-      data2 = closure->data;
-    }
-  callback = (GMarshalFunc_BOOLEAN__FLAGS) (marshal_data ? marshal_data : cc->callback);
-
-  v_return = callback (data1,
-                       g_value_get_flags (param_values + 1),
-                       data2);
-
-  g_value_set_boolean (return_value, v_return);
+  g_value_take_string (return_value, v_return);
 }
 
